import sys


def print_lol(the_list, indent=False, level=0, fn=sys.out):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, indent, level + 1, fn)
        else:
            if indent:
                for tab_stop in range(level):  # 次for循环可替换代码为print('\t'*level,end='')1.3.1
                    print('\t', end='', file=fn)
            print(each_item, file=fn)



from distutils.core import setup

setup(
    name='nester_ht7714',
    version='2.3.1',
    py_modules=['nester'],
    author='hfpython',
    author_email='hfpython@headfirstlabs.com',
    url='http://www.headfirstlabs.com',
    description='A simple printer of nested lists,更新了写入文件',

)
